(DIRECTION TATE)
(FAMILY OTF KANJI)
(FACE F MRR)
(CODINGSCHEME TEX KANJI TEXT)
(DESIGNSIZE R 10.0)
(CHECKSUM O 0)
(SEVENBITSAFEFLAG TRUE)
(FONTDIMEN
   (SLANT R 0.0)
   (SPACE R 0.0)
   (STRETCH R 0.1)
   (SHRINK R 0.0)
   (XHEIGHT R 1.0)
   (QUAD R 1.0)
   (EXTRASPACE R 0.25)
   (EXTRASTRETCH R 0.2)
   (EXTRASHRINK R 0.125)
   )
(CHARSINTYPE O 1
   厨 逗 吹 垂 帥 推 水 炊 睡 粋 翠 衰 遂 酔 錐 錘 随 瑞 髄 崇 嵩 数 枢 趨 雛 据 杉 椙 菅 頗 雀 裾 澄 摺 寸 世 瀬 畝 是 凄 制 勢 姓 征 性 成 政 整 星
   )
(CHARSINTYPE O 2
   振 新 晋 森 榛 浸 深 申 疹 真 神 秦 紳 臣 芯 薪 親 診 身 辛
   )
(CHARSINTYPE O 3
   進 針 震 人 仁 刃 塵 壬 尋 甚 尽 腎 訊 迅 陣 靭 笥 諏 須 酢 図
   )
(TYPE O 0
   (CHARWD R 1.0)
   (CHARHT R 0.5)
   (CHARDP R 0.5)
   )
(TYPE O 1
   (CHARWD R 0.5)
   (CHARHT R 0.5)
   (CHARDP R 0.5)
   )
(TYPE O 2
   (CHARWD R 0.25)
   (CHARHT R 0.5)
   (CHARDP R 0.5)
   )
(TYPE O 3
   (CHARWD R 0.333333)
   (CHARHT R 0.5)
   (CHARDP R 0.5)
   )
