(COMMENT THIS IS A KANJI FORMAT FILE)
(FAMILY UPNMKOR KANJI)
(FACE F MRR)
(CODINGSCHEME TEX KANJI TEXT)
(DESIGNSIZE R 10.0)
(COMMENT DESIGNSIZE IS IN POINTS)
(COMMENT OTHER SIZES ARE MULTIPLES OF DESIGNSIZE)
(CHECKSUM O 0)
(SEVENBITSAFEFLAG TRUE)
(FONTDIMEN
   (SLANT R 0.0)
   (SPACE R 0.0)
   (STRETCH R 0.1)
   (SHRINK R 0.0)
   (XHEIGHT R 1.0)
   (QUAD R 1.0)
   (EXTRASPACE R 0.25)
   (EXTRASTRETCH R 0.2)
   (EXTRASHRINK R 0.125)
   )
(GLUEKERN
   (LABEL O 0)
   (GLUE O 1 R 0.5 R 0.0 R 0.5)
   (GLUE O 3 R 0.25 R 0.0 R 0.25)
   (STOP)
   (LABEL O 1)
   (GLUE O 3 R 0.25 R 0.0 R 0.25)
   (STOP)
   (LABEL O 2)
   (GLUE O 0 R 0.5 R 0.0 R 0.5)
   (GLUE O 1 R 0.5 R 0.0 R 0.5)
   (GLUE O 3 R 0.25 R 0.0 R 0.25)
   (GLUE O 5 R 0.5 R 0.0 R 0.5)
   (STOP)
   (LABEL O 3)
   (GLUE O 0 R 0.25 R 0.0 R 0.25)
   (GLUE O 1 R 0.25 R 0.0 R 0.25)
   (GLUE O 2 R 0.25 R 0.0 R 0.25)
   (GLUE O 3 R 0.5 R 0.0 R 0.25)
   (GLUE O 4 R 0.25 R 0.0 R 0.25)
   (GLUE O 5 R 0.25 R 0.0 R 0.25)
   (STOP)
   (LABEL O 4)
   (GLUE O 0 R 0.5 R 0.0 R 0.0)
   (GLUE O 1 R 0.5 R 0.0 R 0.0)
   (GLUE O 3 R 0.75 R 0.0 R 0.25)
   (GLUE O 5 R 0.5 R 0.0 R 0.0)
   (STOP)
   (LABEL O 5)
   (GLUE O 1 R 0.5 R 0.0 R 0.5)
   (GLUE O 3 R 0.25 R 0.0 R 0.25)
   (KRN O 5 R 0.0)
   (STOP)
   )
(CHARSINTYPE O 1
   ‘ “ （ 〔 ［ ｛ 〈 《 「 『 【 
   UFF5F U3018 U3016 
   U2329 U301A 
   )
(CHARSINTYPE O 2
   、 ， ’ ” ） 〕 ］ ｝ 〉 》 」 』 】 
   UFF60 U3019 U3017 
   U232A U301B 
   )
(CHARSINTYPE O 3
   ・ ： ； 
   U00B7 
   )
(CHARSINTYPE O 4
   。 ． 
   )
(CHARSINTYPE O 5
   — ― … ‥
   )
(TYPE O 0
   (CHARWD R 1.0)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   (COMMENT
      (GLUE O 1 R 0.5 R 0.0 R 0.5)
      (GLUE O 3 R 0.25 R 0.0 R 0.25)
      )
   )
(TYPE O 1
   (CHARWD R 0.5)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   (COMMENT
      (GLUE O 3 R 0.25 R 0.0 R 0.25)
      )
   )
(TYPE O 2
   (CHARWD R 0.5)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   (COMMENT
      (GLUE O 0 R 0.5 R 0.0 R 0.5)
      (GLUE O 1 R 0.5 R 0.0 R 0.5)
      (GLUE O 3 R 0.25 R 0.0 R 0.25)
      (GLUE O 5 R 0.5 R 0.0 R 0.5)
      )
   )
(TYPE O 3
   (CHARWD R 0.5)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   (COMMENT
      (GLUE O 0 R 0.25 R 0.0 R 0.25)
      (GLUE O 1 R 0.25 R 0.0 R 0.25)
      (GLUE O 2 R 0.25 R 0.0 R 0.25)
      (GLUE O 3 R 0.5 R 0.0 R 0.25)
      (GLUE O 4 R 0.25 R 0.0 R 0.25)
      (GLUE O 5 R 0.25 R 0.0 R 0.25)
      )
   )
(TYPE O 4
   (CHARWD R 0.5)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   (COMMENT
      (GLUE O 0 R 0.5 R 0.0 R 0.0)
      (GLUE O 1 R 0.5 R 0.0 R 0.0)
      (GLUE O 3 R 0.75 R 0.0 R 0.25)
      (GLUE O 5 R 0.5 R 0.0 R 0.0)
      )
   )
(TYPE O 5
   (CHARWD R 1.0)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   (COMMENT
      (GLUE O 1 R 0.5 R 0.0 R 0.5)
      (GLUE O 3 R 0.25 R 0.0 R 0.25)
      (KRN O 5 R 0.0)
      )
   )
