(DIRECTION TATE)
(FAMILY OTF KANJI)
(FACE F MRR)
(CODINGSCHEME TEX KANJI TEXT)
(DESIGNSIZE R 10.0)
(CHECKSUM O 0)
(SEVENBITSAFEFLAG TRUE)
(FONTDIMEN
   (SLANT R 0.0)
   (SPACE R 0.0)
   (STRETCH R 0.1)
   (SHRINK R 0.0)
   (XHEIGHT R 1.0)
   (QUAD R 1.0)
   (EXTRASPACE R 0.25)
   (EXTRASTRETCH R 0.2)
   (EXTRASHRINK R 0.125)
   )
(CHARSINTYPE O 1
   紙 紫 肢 脂 至 視 詞 詩 試 誌 諮 資 賜 雌 飼 歯 事 似 侍 児 字 寺 慈 持 時 次 滋 治 爾 璽 痔 磁 示 而 耳 自 蒔 辞 汐 鹿 式 識 鴫 竺 軸 宍 雫 七 叱 執 失 嫉 室 悉 湿 漆 疾 質 実 蔀 篠 偲 柴 芝 屡 蕊 縞 舎 写 射 捨 赦 斜 煮 社 紗 者 謝 車 遮 蛇 邪 借 勺 尺 杓 灼 爵 酌 釈 錫 若 寂 弱 惹 主 取 守 手 朱 殊 狩 珠 種 腫 趣 酒 首 儒 受 呪 寿 授 樹 綬 需 囚 収 周 宗 就 州 修 愁 拾 洲 秀 秋 終 繍 習 臭 舟 蒐 衆 襲 讐 蹴 輯 週 酋 酬 集 醜 什 住 充 十 従 戎 柔 汁 渋 獣 縦 重 銃 叔 夙 宿 淑 祝 縮 粛 塾 熟 出 術 述 俊 峻 春 瞬 竣 舜 駿 准 循 旬 楯 殉 淳 準 潤 盾 純 巡 遵 醇 順 処 初 所 暑 曙 渚 庶 緒 署 書 薯 藷 諸 助 叙 女 序 徐 恕 鋤 除 傷 償 勝 匠 升 召 哨 商 唱 嘗 奨 妾 娼 宵 将 小 少 尚 庄 床 廠 彰 承 抄 招 掌 捷 昇 昌 昭 晶 松 梢 樟 樵 沼 消 渉 湘 焼 焦 照 症 省 硝 礁 祥 称 章 笑 粧 紹 肖 菖 蒋 蕉 衝 裳 訟 証 詔 詳 象 賞 醤 鉦 鍾 鐘 障 鞘 上 丈 丞 乗 冗 剰 城 場 壌 嬢 常 情 擾 条 杖 浄 状 畳 穣 蒸 譲 醸 錠 嘱 埴 飾 拭 植 殖 燭 織 職 色 触 食 蝕 辱 尻 伸 信 侵 唇 娠 寝 審 心 慎 振 新 晋 森 榛 浸 深 申 疹 真 神 秦 紳 臣 芯 薪 親 診 身 辛 進 針 震 人 仁 刃 塵 壬 尋 甚 尽 腎 訊 迅 陣 靭 笥 諏 須 酢 図 厨 逗 吹 垂 帥 推 水 炊 睡 粋 翠 衰 遂 酔 錐 錘 随 瑞 髄 崇 嵩 数 枢 趨 雛 据 杉 椙 菅 頗 雀 裾 澄 摺 寸 世 瀬 畝 是 凄 制 勢 姓 征 性 成 政 整 星 晴 棲 栖 正 清 牲 生 盛 精 聖 声 製 西 誠 誓 請 逝 醒 青 静 斉 税 脆 隻 席 惜 戚 斥 昔 析 石 積 籍 績 脊 責 赤 跡 蹟 碩 切 拙 接 摂 折 設 窃 節 説 雪 絶 舌 蝉 仙 先 千 占 宣 専 尖 川 戦 扇 撰 栓 栴 泉 浅 洗 染 潜 煎 煽 旋 穿 箭 線 繊 羨 腺 舛 船 薦 詮 賎 践 選 遷 銭 銑 閃 鮮 前 善 漸 然 全 禅 繕 膳 糎 噌 塑 岨 措 曾 曽 楚 狙 疏 疎 礎 祖 租 粗 素 組 蘇 訴 阻 遡 鼠 僧 創 双 叢 倉 喪 壮 奏 爽 宋 層 匝 惣 想 捜 掃 挿 掻 操 早 曹 巣 槍 槽 漕 燥 争 痩 相 窓 糟 総 綜 聡 草 荘 葬 蒼 藻 装 走 送 遭 鎗 霜 騒 像 増 憎 臓 蔵 贈 造 促 側 則 即 息 捉 束 測 足 速 俗 属 賊 族 続 卒 袖 其 揃 存 孫 蝋 郎 六 麓 禄 肋 録 論 倭 和 話
   )
(TYPE O 0
   (CHARWD R 1.0)
   (CHARHT R 0.5)
   (CHARDP R 0.5)
   )
(TYPE O 1
   (CHARWD R 0.5)
   (CHARHT R 0.5)
   (CHARDP R 0.5)
   )
