(FAMILY OTF KANJI)
(FACE F MRR)
(CODINGSCHEME TEX KANJI TEXT)
(DESIGNSIZE R 10.0)
(CHECKSUM O 0)
(SEVENBITSAFEFLAG TRUE)
(FONTDIMEN
   (SLANT R 0.0)
   (SPACE R 0.0)
   (STRETCH R 0.1)
   (SHRINK R 0.0)
   (XHEIGHT R 1.0)
   (QUAD R 1.0)
   (EXTRASPACE R 0.25)
   (EXTRASTRETCH R 0.2)
   (EXTRASHRINK R 0.125)
   )
(CHARSINTYPE O 1
   革 学 岳 楽 額 顎 掛 笠 樫 橿 梶 鰍 潟 割 喝 恰 括 活 渇 滑 葛 褐 轄 且 鰹 叶 椛 樺 鞄 株 兜 竃 蒲 釜 鎌 噛 鴨 栢 茅 萱 粥 刈 苅 瓦 乾 侃 冠 寒 刊 勘 勧 巻 喚 堪 姦 完 官 寛 干 幹 患 感 慣 憾 換 敢 柑 桓 棺 款 歓 汗 漢 澗 潅 環 甘 監 看 竿 管 簡 緩 缶 翰 肝 艦 莞 観 諌 貫 還 鑑 間 閑 関 陥 韓 館 舘 丸 含 岸 巌 玩 癌 眼 岩 翫 贋 雁 頑 顔 願 企 伎 危 喜 器 基 奇 嬉 寄 岐 希 幾 忌 揮 机 旗 既 期 棋 棄 機 帰 毅 気 汽 畿 祈 季 稀 紀 徽 規 記 貴 起 軌 輝 飢 騎 鬼 亀 偽 儀 妓 宜 戯 技 擬 欺 犠 疑 祇 義 蟻 誼 議 掬 菊 鞠 吉 吃 喫 桔 橘 詰 砧 杵 黍 却 客 脚 虐 逆 丘 久 仇 休 及 吸 宮 弓 急 救 朽 求 汲 泣 灸 球 究 窮 笈 級 糾 給 旧 牛 去 居 巨 拒 拠 挙 渠 虚 許 距 鋸 漁 禦 魚 亨 享 京 供 侠 僑 兇 競 共 凶 協 匡 卿 叫 喬 境 峡 強 彊 怯 恐 恭 挟 教 橋 況 狂 狭 矯 胸 脅 興 蕎 郷 鏡 響 饗 驚 仰 凝 尭 暁 業 局 曲 極 玉 桐 粁 僅 勤 均 巾 錦 斤 欣 欽 琴 禁 禽 筋 緊 芹 菌 衿 襟 謹 近 金 吟 銀 九 倶 句 区 狗 玖 矩 苦 躯 駆 駈 駒 具 愚 虞 喰 空 偶 寓 遇 隅 串 櫛 釧 屑 屈 掘 窟 沓 靴 轡 窪 熊 隈 粂 栗 繰 桑 鍬 勲 君 薫 訓 群 軍 郡 卦 袈 祁 係 傾 刑 兄 啓 圭 珪 型 契 形 径 恵 慶 慧 憩 掲 携 敬 景 桂 渓 畦 稽 系 経 継 繋 罫 茎 荊 蛍 計 詣 警 軽 頚 鶏 芸 迎 鯨 劇 戟 撃 激 隙 桁 傑 欠 決 潔 穴 結 血 訣 月 件 倹 倦 健 兼 券 剣 喧 圏 堅 嫌 建 憲 懸 拳 捲 検 権 牽 犬 献 研 硯 絹 県 肩 見 謙 賢 軒 遣 鍵 険 顕 験 鹸 元 原 厳 幻 弦 減 源 玄 現 絃 舷 言 諺 限 乎 個 古 呼 固 姑 孤 己 庫 弧 戸 故 枯 湖 狐 糊 袴 股 胡 菰 虎 誇 跨 鈷 雇 顧 鼓 五 互 伍 午 呉 吾 娯 後 御 悟 梧 檎 瑚 碁 語 誤 護 醐 乞 鯉 交 佼 侯 候 倖 光 公 功 効 勾 厚 口 向 后 喉 坑 垢 好 孔 孝 宏 工 巧 巷 幸 広 庚 康 弘 恒 慌 抗 拘 控 攻 昂 晃 更 杭 校 梗 構 江 洪 浩 港 溝 甲 皇 硬 稿 糠 紅 紘 絞 綱 耕 考 肯 肱 腔 膏 航 荒 行 衡 講 貢 購 郊 酵 鉱 砿 鋼 閤 降 項 香 高 鴻 剛 劫 号 合 壕
   )
(TYPE O 0
   (CHARWD R 1.0)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   )
(TYPE O 1
   (CHARWD R 0.5)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   )
