(FAMILY OTF KANJI)
(FACE F MRR)
(CODINGSCHEME TEX KANJI TEXT)
(DESIGNSIZE R 10.0)
(CHECKSUM O 0)
(SEVENBITSAFEFLAG TRUE)
(FONTDIMEN
   (SLANT R 0.0)
   (SPACE R 0.0)
   (STRETCH R 0.1)
   (SHRINK R 0.0)
   (XHEIGHT R 1.0)
   (QUAD R 1.0)
   (EXTRASPACE R 0.25)
   (EXTRASTRETCH R 0.2)
   (EXTRASHRINK R 0.125)
   )
(CHARSINTYPE O 1
   絃 舷 賚 賽 賺 賻 贄 贅 贊 贇 贏 贍 贐 齎 贓 賍 贔 贖 赧 赭 赱 赳 趁 趙 跂 趾 趺
   )
(CHARSINTYPE O 2
   蛤 隼 伴 判 半 反 叛 帆 搬 斑 板 氾 汎 版 犯 班 畔 繁 般 藩
   )
(CHARSINTYPE O 3
   販 範 釆 煩 頒 飯 挽 晩 番 盤 磐 蕃 蛮 匪 卑 否 妃 庇 彼 悲 扉
   )
(TYPE O 0
   (CHARWD R 1.0)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   )
(TYPE O 1
   (CHARWD R 0.5)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   )
(TYPE O 2
   (CHARWD R 0.25)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   )
(TYPE O 3
   (CHARWD R 0.333333)
   (CHARHT R 0.88)
   (CHARDP R 0.12)
   )
   